## Keynotes

###   

#### The last lighthouse: Free software in dark times

[Edward Snowden](), [Daniel Kahn Gillmor]()

RoomTBA

Join NSA Whistleblower Edward Snowden and ACLU Technologist Daniel Kahn Gillmor for a discussion about free software, surveillance, power, and control of the future.

## Sessions

###    

#### Advocate for Yourself at Work: Use More Free Software and Keep Contributing to the Community

[Deb Nicholson](), [Richard Fontana]()

RoomTBA

Your workplace can exert a lot of control over how much free software you use, what you're allowed to work on in your own time and what kinds of tools you become an expert in. New employees don't always negotiate their contracts to make sure they can continue contributing to free software and current employees aren't always successful at advocating for using free software tools, choosing free software technologies or contributing changes back upstream when they do rely on free software. We'll address what's possible, what your legal department is likely to be concerned about and how to be a smooth negotiator at work. Many companies could benefit tremendously from using Free and Open Source Software, but free software enthusiasts and institutional gatekeepers are coming from very different perspectives. Free software developers and users tend to be most familiar with free software's benefits when compared to proprietary solutions; user freedom, reusing code, public code review for bugs, increased project capacity and cost. The uninitiated may -- unfortunately -- be most familiar with the risks, some real and some perceived. Employers also benefit from having workers who are passionate about their work, are well-connected to the free software community and are constantly learning about new technologies from their peers outside the company, but new employee contracts rarely recognize this unless you ask. Conversations about contracts, choosing new technologies and sharing an employee's work with another entity are high stakes negotiations. With a solid understanding of what worries and motivates the other parties, you can become a savvy advocate for free software at work. This talk will help you gather information, frame the conversation and make the best possible case for using and contributing to free software at work.

#### Building new economies for open development and content

[Paige Peterson](), MaidSoft

RoomTBA

Shifting perspectives on the value of Free/Libre software development and Creative Commons content creation would open up opportunities for individuals working in these fields as we finally see a push towards an economy that makes sense for the Internet. This will be an overview of some platforms creating these new opportunities and ways we can think about how an economy can exist in the digital world beyond the artificial scarcity that comes with keeping code and content locked down or secret. The session should include group discussion about platforms, philosophies and experiences folks working in free/libre software and creative commons content.

#### Challenges and future growth in libre media and conference video production

[George Chriss](), [Kat Walsh]() (moderator)

RoomTBA

An 'intermediate' panel designed to provide a working overview of diversified libre media communities blended with per-project technical development updates, organizational adoption challenges, community-centric user-experience goals and other novel discussions regarding video production both generally and as it relates to conference video production (e.g., session recording and live-streaming).

#### A community take on the license compliance industry

[Stefano Zacchiroli](), Debian, OSI, IRILL

RoomTBA

The license compliance industry purportedly helps information technology companies and other actors to use publicly available software, and in particular free software, in a way that is compliant with the relevant free software licenses. In this talk we will review why the license compliance industry exists and discuss, from an external point of view, how it operates. We will then highlight some potential ethical issues on the current best practices for license compliance in the industry, and propose community-oriented alternatives that we can build, today, on top of the existing corpus of publicly available free software.


#### Free software alternatives to dominant proprietary solutions: A review of French initiatives

[Marianne Corvellec](), April and [Jonathan Le Lous](), April

RoomTBA

[Project "De-google-ify Internet"](https://degooglisons-internet.org/?l=en) aims at offering as many alternative services as possible to those threatening our digital freedoms. Google" is not the only player there, even though it gave the project its name. Google Drive, Google Calendar, Skype, Dropbox, Facebook, Twitter, Youtube, Doodle, Yahoo Groups, and many others, are extremely convenient services. But they are centralized and make users dependent.

Framasoft are resisting this trend. They have come up with a several year roadmap to set up alternative services. These services are thought of as digital commons. They are free, gratis, and open to all. Framasoft is a French not-for-profit whose goal is to decentralize the Internet by promoting self-hosting. They work to empower everyone to install and run their own services. The project already offers more than 15 alternative services and welcomes about 1,000,000 visits per month.

#### GNU/Linux and Chill: Free Software on a College Campus

[Michaela R. Brown]()

RoomTBA

Being a free software user isn't easy,  especially when you're a college student. I spent a year at a school that taught Visual Basic as its primary programming language for freshmen and sophomores, where "Introduction to Programming" was an overview of the Windows OS, and where most of the professors would only accept papers typed in Times New Roman -- and I survived. In this session, I'll give students tips for making it through college while still adhering to the values we hold as free software users -- including alternative fonts, making a GNU/Linux live disk for use on public computers, avoiding the "Netflix and Chill" dilemma, and most importantly, ways to discuss free software with professors and fellow students. After leaving this session, students will feel empowered and able to hold their own as free users in a proprietary campus.

#### LittleSis: Mapping the powers that be

[Molly Gott]()

RoomTBA

LittleSis is a free software, wiki-style database that tracks connections between the world's most powerful people and organizations. In the workshop, participants will be trained in the site's basic functions (e.g. editing profile pages and searching for interlocks between corporations) and advanced functions (e.g using the site's Oligrapher tool to create maps of information stored in the database). We will also share stories about the ways in which LittleSis and power analysis research have been used in movement and organizing contexts, including how activists in St. Louis used LittleSis to map and challenge the local corporate Powers Behind the Police and how activists in Philadelphia are using LittleSis to research the corporate entities behind education privatization. Participants will leave with an understanding of how to use LittleSis, as well as inspiration for how they can start their own movement research teams to map the powers that be in their communities.

#### Solving the deployment crisis with GNU Guix

[Christopher Webber](), [David Thompson](), [Ludovic Courtès]()

RoomTBA

User freedom is threatened by the growing complexity of current deployment and packaging directions.  Running software (especially server/networked software) is becoming too hard for the average user, so many users are turning to the dangerous path of relying on large corporations to do their computing for them.  What can GNU do to turn the tide here?  Enter GNU Guix and GuixSD!  This talk will walk through Guix's unique positioning to provide totally free and reproducible systems.  A path will be laid out on how Guix could be used as a foundation for easy to run and maintain computing for everyone, how you can get Guix and GuixSD running, and how to get involved in the most hacking-friendly package manager/distro duo ever!

